habitat.parser_modules.simple_binary_parser
===========================================

.. automodule:: habitat.parser_modules.simple_binary_parser

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      ParserModule
      SimpleBinaryParser
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      CantExtractCallsign
   
   